==> jc-1.4.0.tar.gz: gnu/java/awt/color/CieXyzConverter.h <==
// public class gnu.java.awt.color.CieXyzConverter

// class file dependencies
// @dep_class 63ca286863ab171a gnu_java_awt_color_CieXyzConverter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_CieXyzConverter_H_
#define _JC_gnu_java_awt_color_CieXyzConverter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_CieXyzConverter$sub_refs	_jc_gnu_java_awt_color_CieXyzConverter$sub_refs;
typedef struct _jc_gnu_java_awt_color_CieXyzConverter$sub_nonrefs	_jc_gnu_java_awt_color_CieXyzConverter$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_CieXyzConverter$refs	_jc_gnu_java_awt_color_CieXyzConverter$refs;
typedef struct _jc_gnu_java_awt_color_CieXyzConverter$nonrefs	_jc_gnu_java_awt_color_CieXyzConverter$nonrefs;
typedef struct _jc_gnu_java_awt_color_CieXyzConverter$object	_jc_gnu_java_awt_color_CieXyzConverter$object;

typedef const struct _jc_gnu_java_awt_color_CieXyzConverter$vmethods	_jc_gnu_java_awt_color_CieXyzConverter$vmethods;
typedef const struct _jc_gnu_java_awt_color_CieXyzConverter$vtable	_jc_gnu_java_awt_color_CieXyzConverter$vtable;
typedef const struct _jc_gnu_java_awt_color_CieXyzConverter$vtype	_jc_gnu_java_awt_color_CieXyzConverter$vtype;

// Constructors
extern void _jc_gnu_java_awt_color_CieXyzConverter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *);

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_CieXyzConverter$method$fromCIEXYZ$7b319ba108c72c43(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_CieXyzConverter$method$fromRGB$241337c328fb6c81(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_CieXyzConverter$method$toCIEXYZ$ea146856208217b9(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_CieXyzConverter$method$toRGB$8e7372c09e81aa9c(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_CieXyzConverter$method_info$fromCIEXYZ$7b319ba108c72c43;
extern _jc_method _jc_gnu_java_awt_color_CieXyzConverter$method_info$fromRGB$241337c328fb6c81;
extern _jc_method _jc_gnu_java_awt_color_CieXyzConverter$method_info$toCIEXYZ$ea146856208217b9;
extern _jc_method _jc_gnu_java_awt_color_CieXyzConverter$method_info$toRGB$8e7372c09e81aa9c;

// Virtual methods structure
struct _jc_gnu_java_awt_color_CieXyzConverter$vmethods {
	_jc_float_array	*(*fromCIEXYZ$7b319ba108c72c43)(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*fromRGB$241337c328fb6c81)(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*toCIEXYZ$ea146856208217b9)(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*toRGB$8e7372c09e81aa9c)(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *);
};

// Vtable
struct _jc_gnu_java_awt_color_CieXyzConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_CieXyzConverter$vmethods	gnu_java_awt_color_CieXyzConverter;
};

// Vtype
struct _jc_gnu_java_awt_color_CieXyzConverter$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_CieXyzConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_CieXyzConverter$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_CieXyzConverter$refs {
    _jc_gnu_java_awt_color_CieXyzConverter$sub_refs	gnu_java_awt_color_CieXyzConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_CieXyzConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_CieXyzConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_CieXyzConverter$sub_nonrefs	gnu_java_awt_color_CieXyzConverter;
};

// Object instance structure
struct _jc_gnu_java_awt_color_CieXyzConverter$object {
	_jc_gnu_java_awt_color_CieXyzConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_CieXyzConverter$vtype	*vtype;
	_jc_gnu_java_awt_color_CieXyzConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_CieXyzConverter$vtype _jc_gnu_java_awt_color_CieXyzConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_CieXyzConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_CieXyzConverter$class_object;

#endif	/* _JC_gnu_java_awt_color_CieXyzConverter_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/color/CieXyzConverter.h <==
// public class gnu.java.awt.color.CieXyzConverter

// class file dependencies
// @dep_class 1ada824bcf061ae2 gnu_java_awt_color_CieXyzConverter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_CieXyzConverter_H_
#define _JC_gnu_java_awt_color_CieXyzConverter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_CieXyzConverter$sub_refs	_jc_gnu_java_awt_color_CieXyzConverter$sub_refs;
typedef struct _jc_gnu_java_awt_color_CieXyzConverter$sub_nonrefs	_jc_gnu_java_awt_color_CieXyzConverter$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_CieXyzConverter$refs	_jc_gnu_java_awt_color_CieXyzConverter$refs;
typedef struct _jc_gnu_java_awt_color_CieXyzConverter$nonrefs	_jc_gnu_java_awt_color_CieXyzConverter$nonrefs;
typedef struct _jc_gnu_java_awt_color_CieXyzConverter$object	_jc_gnu_java_awt_color_CieXyzConverter$object;

typedef const struct _jc_gnu_java_awt_color_CieXyzConverter$vmethods	_jc_gnu_java_awt_color_CieXyzConverter$vmethods;
typedef const struct _jc_gnu_java_awt_color_CieXyzConverter$vtable	_jc_gnu_java_awt_color_CieXyzConverter$vtable;
typedef const struct _jc_gnu_java_awt_color_CieXyzConverter$vtype	_jc_gnu_java_awt_color_CieXyzConverter$vtype;

// Constructors
extern void _jc_gnu_java_awt_color_CieXyzConverter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_CieXyzConverter$method$fromCIEXYZ$7b319ba108c72c43(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_CieXyzConverter$method$fromRGB$241337c328fb6c81(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_CieXyzConverter$method$toCIEXYZ$ea146856208217b9(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_CieXyzConverter$method$toRGB$8e7372c09e81aa9c(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_CieXyzConverter$method_info$fromCIEXYZ$7b319ba108c72c43;
extern _jc_method _jc_gnu_java_awt_color_CieXyzConverter$method_info$fromRGB$241337c328fb6c81;
extern _jc_method _jc_gnu_java_awt_color_CieXyzConverter$method_info$toCIEXYZ$ea146856208217b9;
extern _jc_method _jc_gnu_java_awt_color_CieXyzConverter$method_info$toRGB$8e7372c09e81aa9c;

// Virtual methods structure
struct _jc_gnu_java_awt_color_CieXyzConverter$vmethods {
	_jc_float_array	*(*fromCIEXYZ$7b319ba108c72c43)(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*fromRGB$241337c328fb6c81)(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*toCIEXYZ$ea146856208217b9)(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*toRGB$8e7372c09e81aa9c)(_jc_env *, struct _jc_gnu_java_awt_color_CieXyzConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_color_CieXyzConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_CieXyzConverter$vmethods	gnu_java_awt_color_CieXyzConverter;
};

// Vtype
struct _jc_gnu_java_awt_color_CieXyzConverter$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_CieXyzConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_CieXyzConverter$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_CieXyzConverter$refs {
    _jc_gnu_java_awt_color_CieXyzConverter$sub_refs	gnu_java_awt_color_CieXyzConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_CieXyzConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_CieXyzConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_CieXyzConverter$sub_nonrefs	gnu_java_awt_color_CieXyzConverter;
};

// Object instance structure
struct _jc_gnu_java_awt_color_CieXyzConverter$object {
	_jc_gnu_java_awt_color_CieXyzConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_CieXyzConverter$vtype	*vtype;
	_jc_gnu_java_awt_color_CieXyzConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_CieXyzConverter$vtype _jc_gnu_java_awt_color_CieXyzConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_CieXyzConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_CieXyzConverter$class_object;

#endif	/* _JC_gnu_java_awt_color_CieXyzConverter_H_ */
